/////////////////////////////////////////////////////////////////////////////
// Project:     wxIView
// Purpose:     Complex wxWidgets sample
// Name:        wxextfiledroptarget.h
// Author:      Daniel Nell
// Created:     2006/02/16
// Copyright:   (c) Daniel Nell
// Licence:     wxWindows licence
// Modified by:
/////////////////////////////////////////////////////////////////////////////

#ifndef __WXEXTFILEDROPTARGET_H
#define __WXEXTFILEDROPTARGET_H

// Include additional wxWidgets headers.
#include <wx/dnd.h>


/////////////////////////////////////////////////////////////////////////////
//  Class wxExtFileDropEvent
//
BEGIN_DECLARE_EVENT_TYPES()
    DECLARE_LOCAL_EVENT_TYPE( wxEVT_EXTFILEDROP, 0 )
END_DECLARE_EVENT_TYPES()

/// \brief Generic file drop event.
///
/// This class extends wxEvent to transport a file name to the event handler
/// that proecesses the file drop event. File drop events are created by
/// wxExtFileDropTarget objects.
class wxExtFileDropEvent : public wxEvent
{
  public:
    /// Constructor
    wxExtFileDropEvent( wxEventType oType= wxEVT_EXTFILEDROP )
      : wxEvent( 0, oType )
    {
        m_strFileName.Clear();
    }

    /// Copy constructor.
    wxExtFileDropEvent( const wxExtFileDropEvent& oEvent )
      : wxEvent( oEvent )
    {
        SetFileName( oEvent.m_strFileName );
    }

    /// Return a copy of this event.
    virtual wxEvent *Clone() const
    {
        return new wxExtFileDropEvent( *this );
    }

    /// Set the file name.
    void SetFileName( wxString strFileName )
    {
        m_strFileName= strFileName;
    }

    /// Get the filename.
    wxString GetFileName()
    {
        return m_strFileName;
    }

  private:
    wxString m_strFileName;
};

typedef void (wxEvtHandler::*wxExtFileDropEventEventFunction)( wxExtFileDropEvent& );

#define wxExtFileDropEventEventHandler(func) \
    (wxObjectEventFunction)(wxEventFunction)wxStaticCastEvent( wxExtFileDropEventEventFunction, &func )

#define EVT_EXTFILEDROP(func) \
   wx__DECLARE_EVT0( wxEVT_EXTFILEDROP, wxExtFileDropEventEventHandler( func ) )


/////////////////////////////////////////////////////////////////////////////
//  Class wxExtFileDropTarget
//
/// \brief The file drop handler (file drop target).
///
/// This is a generic helper class for file dropping. Use
///     SetDropTarget( new wxExtFileDropTarget( this ) );
/// and install a handler for EVT_EXTFILEDROP( XXX::OnFileDrop ) in a class
/// XXX derived from wxWindow to use this class.
class wxExtFileDropTarget : public wxFileDropTarget
{
  public:
    /// \brief Standard constructor
    ///
    /// \param poOwner    a pointer to the owner window.
    wxExtFileDropTarget( wxWindow *poOwner )
    {
        m_poOwner= poOwner;
    }

    /// \brief Handler for file dropping.
    ///
    /// \param x                unused.
    /// \param y                unused.
    /// \param astrFilenames    string array of the dropped file names..
    virtual bool OnDropFiles( wxCoord x, wxCoord y, const wxArrayString& astrFilenames );

  private:
    // Member variables
    wxWindow *m_poOwner;            ///< Internal pointer to the owner window.
};

#endif // __WXEXTFILEDROPTARGET_H
